<?php

/**
 * Enqueue styles & scripts class
 *
 * Used for loading styles and scripts for specific view files
 * @package otys-jobs-apply
 */

namespace Otys\OtysPlugin\Includes\Core;

class Enqueue extends Base
{
    private static $scripts = array();
    private static $styles = array();

    public function __construct()
    {
        Hooks::addAction('otys_load_style', Enqueue::class, 'addStyle', 1, 5);
        Hooks::addAction('otys_load_script', Enqueue::class, 'addScript', 1, 5);
        Hooks::addAction('wp_enqueue_scripts', __CLASS__, 'load');
        Hooks::addAction('init', __CLASS__, 'init');
    }

    /**
     * Init styles
     *
     * @return void
     */
    public static function init()
    {
        // Enqueue default plugin styling
        static::addStyle(['handle' => 'bootstrap','src' => OTYS_PLUGIN_ASSETS_URL . '/css/vendors/bootstrap-grid.css']);
        static::addStyle(['handle' => 'otys-jobs-apply-css','src' => OTYS_PLUGIN_ASSETS_URL . '/css/otys-jobs-apply.css']);
        
        if (current_user_can('manage_options')) {
            static::addStyle(['handle' => 'otys-jobs-apply-admin-front-css','src' => OTYS_PLUGIN_ASSETS_URL . '/css/admin/admin_front.css']);
        }
    }

    /**
     * Add style to list of enqueue
     *
     * @param array $args
     * @return void
     * @since 1.0.0
     */
    public static function addStyle(array $args)
    {
        $args = wp_parse_args(
            $args,
            array(
                'handle' => false,
                'src' => false,
                'deps' => array(),
                'ver' => false,
                'media' => 'all',
                'type' => 'style'
            )
        );

        self::$styles[] = $args;
    }

    /**
     * Add script file to list to enqueue
     *
     * @param [type] $args
     * @return void
     * @since 1.0.0
     */
    public static function addScript(array $args): void
    {
        $args = wp_parse_args(
            $args,
            array(
                'handle' => false,
                'src' => false,
                'deps' => array(),
                'ver' => false,
                'in_footer' => true,
            )
        );

        self::$scripts[] = $args;
    }

    /**
     * Enqueue scripts
     *
     * @return void
     * @since 1.0.0
     */
    public static function load(): void
    {
        foreach (self::$styles as $style) {
            wp_enqueue_style($style['handle'], $style['src'], $style['deps'], $style['ver'], $style['media']);
        }

        foreach (self::$scripts as $script) {
            wp_enqueue_script($script['handle'], $script['src'], $script['deps'], $script['ver'], $script['in_footer']);
        }
    }
}
