<?php

namespace Otys\OtysPlugin\Includes\Core;

class Logs extends Base
{
    public function __construct()
    {
        // Make checklogs available via hook
        Hooks::addAction('otys_log_cron', static::class, 'checklogs');

        // Runn add cron on init
        Hooks::addAction('init', static::class, 'addCron');
    }

    /**
     * Create logs table
     *
     * @return mixed
     * @since 1.0.0
     */
    public static function createTable()
    {
        global $wpdb;

        // set the default character set and collation for the table
        $charset_collate = $wpdb->get_charset_collate();

        // Check that the table does not already exist before continuing
        $sql = "CREATE TABLE IF NOT EXISTS `{$wpdb->base_prefix}otys_log` (
        `id` INT(11) NULL AUTO_INCREMENT,
        `request` TEXT NULL,
        `response` TEXT NULL,
        `timestamp` INT(11) NULL,
        INDEX `id` (`id`)
        ) $charset_collate;";

        require_once ABSPATH . 'wp-admin/includes/upgrade.php';

        dbDelta($sql);
        $is_error = empty($wpdb->last_error);

        return $is_error;
    }

    /**
     * Delte table
     *
     * @return mixed
     * @since 1.0.0
     */
    public static function deleteTable()
    {
        global $wpdb;

        $query = "DROP TABLE IF EXISTS `{$wpdb->base_prefix}otys_log`";

        $wpdb->query($query);

        $is_error = empty($wpdb->last_error);

        return $is_error;
    }

    /**
     * Add log related crons
     *
     * @return void
     * @since 1.0.0
     */
    public static function addCron()
    {
        if (!wp_next_scheduled('otys_log_cron')) {
            wp_schedule_event(time(), 'daily', 'otys_log_cron');
        }
    }

    /**
     * Add request and response to LOG
     *
     * @param mixed $request array or JSON string
     * @param mixed $response array or JSON string
     * @return mixed
     * @since 1.0.0
     */
    public static function add($request, $response)
    {
        global $wpdb;

        $request = !is_string($request) ? json_encode($request) : $request;
        $response = !is_string($response) ? json_encode($response) : $response;

        return $wpdb->insert("{$wpdb->base_prefix}otys_log", [
            'request' => $request,
            'response' => $response,
            'timestamp' => strtotime(current_time('mysql'))
        ]);
    }

    /**
     * Get list of logs
     *
     * @return array
     */
    public static function getList(): array
    {
        global $wpdb;

        $sql = "SELECT * FROM `{$wpdb->base_prefix}otys_log` ORDER BY `id` DESC";

        return $wpdb->get_results(
            $sql,
            ARRAY_A
        );
    }

    /**
     * Delete all logs
     *
     * @return mixed
     */
    public static function deleteLogs()
    {
        global $wpdb;

        $sql  = "DELETE FROM `wp_otys_log`";

        return $wpdb->query(
            $sql,
            ARRAY_A
        );
    }

    /**
     * Check logs
     *
     * Removes logs which are older than 1 day
     *
     * @return mixed
     */
    public static function checkLogs()
    {
        global $wpdb;

        $sql  = "DELETE FROM `wp_otys_log` WHERE timestamp < (UNIX_TIMESTAMP() - 86400)";

        return $wpdb->query(
            $sql,
            ARRAY_A
        );
    }
}
