<?php

namespace Otys\OtysPlugin\Includes\OtysApi;

class Mail extends OtysApiBase
{
    /**
     * Send email
     *
     * @param array $args
     * @param boolean $useEmptyMail
     * @param int $userId
     * @return mixed
     */
    public function send($args = [], $useEmptyMail = true, int $userId = 0)
    {
        if ($useEmptyMail === true && isset($args['htmlMessage'])) {
            if (!empty($emptyMail = $this->getEmptyMail($userId))) {
                $args['htmlMessage'] = str_replace('<!--BODY-->', $args['htmlMessage'], $emptyMail['htmlMessage']);
            }
        }

        $request = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.EmailService.send",
            "params" => [
                $this->otysApi->session,
                $args
            ],
            "id" => 1
        ];

        $response = $this->post($request, false, false);

        return $response;
    }

    /**
     * Get empty email including user email signature
     *
     * @return array
     */
    public function getEmptyMail(int $userId = 0): array
    {
        if ($userId === 0) {
            $request = [
                "jsonrpc" => "2.0",
                "method" => "Otys.Services.EmailService.getEmptyMessage",
                "params" => [
                    $this->otysApi->session
                ],
                "id" => 1
            ];
        } else {
            // Get client id
            if ($clientId = $this->otysApi->getClientId()) {
                $request = [
                    "jsonrpc" => "2.0",
                    "method" => "Otys.Services.EmailService.getEmptyMessageForUser",
                    "params" => [
                        $this->otysApi->session,
                        $clientId,
                        $userId
                    ],
                    "id" => 1
                ];
            } else {
                return [];
            }
        }

        $response = $this->post($request, false, true);

        return $response;
    }
}
