<?php

namespace Otys\OtysPlugin\Includes\OtysApi;

class Procedures extends OtysApiBase
{
    /**
     * Get procedure status list of 1,2 & 3
     *
     * @param integer $statusType
     * @return array
     */
    public function getLists(): array
    {
        $request = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.MultiService.execute",
            "params" => [
                [
                    [
                        "method" => "Otys.Services.ProcedureStatus1Service.getList",
                        "args" => [
                            $this->otysApi->session,
                            [
                                "limit" => 500,
                                "condition" => null,
                                "excludeLimitCheck" => true,
                                "what" => [
                                    "uid" => true,
                                    "code" => true,
                                    "automaticallySelectEvent" => true
                                ]
                            ]
                        ]
                    ],
                    [
                        "method" => "Otys.Services.ProcedureStatus2Service.getList",
                        "args" => [
                            $this->otysApi->session,
                            [
                                "limit" => 500,
                                "condition" => null,
                                "excludeLimitCheck" => true,
                                "what" => [
                                    "uid" => true,
                                    "code" => true,
                                    "automaticallySelectEvent" => true
                                ]
                            ]
                        ]
                    ],
                    [
                        "method" => "Otys.Services.ProcedureStatus3Service.getList",
                        "args" => [
                            $this->otysApi->session,
                            [
                                "limit" => 500,
                                "condition" => null,
                                "excludeLimitCheck" => true,
                                "what" => [
                                    "uid" => true,
                                    "code" => true,
                                    "automaticallySelectEvent" => true
                                ]
                            ]
                        ]
                    ]
                ],
            ],
            "id" => 1
        ];

        $result = $this->post($request, true);

        if ($result && ($return = $result)) {
            return $return;
        }

        return [];
    }

    /**
     * Get Status auto select
     * Gets which status to autoselect. There are 4 options which autoselect
     *
     * "1": "Joined via website",
     * "2": "Joined via match",
     * "3": "Joined via vendor management portal",
     * "4": "Use for introduce batch action"
     * 
     * @param integer $autoSelectId Can be status 1, 2, 3 or 4
     * @return void
     */
    public function getStatusAutoSelect(int $autoSelectId)
    {
        $procedureLists = $this->getLists();

        $return =  [];

        // Loop through procedureStatus 1,2,3
        foreach ($procedureLists as $procedureListKey => $procedureList) {
            // Assign procedure service number which can be 1,2 or 3. Need to add 1 because array starts with 0
            $procedureServiceNumber = $procedureListKey + 1;

            /** 
             * Loop through the procedure options and check if the auto select event equals the autoselet id
             * and add the current option to the resulting array and continue with the next procedurestatus since
             * only one option can be marked as auto select each procedurestatus
             */
            foreach ($procedureList["data"] as $procedureOption) {
                if ($procedureOption["automaticallySelectEvent"] == $autoSelectId) {
                    $return[$procedureServiceNumber] = $procedureOption;

                    continue;
                }
            }
        }

        return $return;
    }

    /**
     * Add procedure
     * Create a procedure linked to a candidate and vacancy.
     *
     * @param string $candidateUid
     * @param string $vacancyUid
     * @return array
     * @since 1.0.0
     */
    public function add(string $candidateUid = null, string $vacancyUid = null, array $args = []): array
    {
        if ($candidateUid === null || $vacancyUid === null) {
            return [];
        }

        $requestArgs = [
            "candidateUid" => "{$candidateUid}",
            "vacancyUid" => "{$vacancyUid}"
        ];

        $requestArgs = array_merge($requestArgs, $args);

        $request = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.MultiService.execute",
            "params" => [
                [
                    [
                        "method" => "Otys.Services.ProcedureService.add",
                        "args" => [
                            $this->otysApi->session,
                            $requestArgs
                        ]
                    ]
                ]
            ],
            "id" => 1
        ];

        return $this->post($request, false, false);

        return [];
    }
}
