<?php

namespace Otys\OtysPlugin\Includes\OtysApi;

class Relations extends OtysApiBase
{
    public function get(int $id): array
    {
        // Create OWS request
        $matchCriteriaRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.RelationService.getDetail",
            "params" => [
                $this->otysApi->session,
                $id,
                [
                    "uid" => 1,
                    "is_klantid" => 1,
                    "entryDateTime" => 1,
                    "modifiedBy" => 1,
                    "createdByUser" => 1,
                    "lastModified" => 1,
                    "lastCommercialContact" => 1,
                    "customerNr" => 1,
                    "customerNumber" => 1,
                    "relation" => 1,
                    "relationStatuary" => 1,
                    "email" => 1,
                    "website" => 1,
                    "status" => 1,
                    "statusId" => 1,
                    "user" => 1,
                    "userId" => 1,
                    "types" => 1,
                    "subtypes" => 1,
                    "sectors" => 1,
                    "skype" => 1,
                    "phoneNumberMain" => 1,
                    "phoneNumberFax" => 1,
                    "customerPortal" => 1,
                    "billingCode1" => 1,
                    "billingCode2" => 1,
                    "billingCode3" => 1,
                    "debtorNrInternal" => 1,
                    "ibsNr" => 1,
                    "flexserviceNr" => 1,
                    "afasNr" => 1,
                    "bankAccountName" => 1,
                    "bankAccountHolderName" => 1,
                    "bankAccountType" => 1,
                    "bankAccountNr" => 1,
                    "ibanNr" => 1,
                    "bicNr" => 1,
                    "vatNr" => 1,
                    "cocNr" => 1,
                    "BusinessRegLocation" => 1,
                    "debtorScenario" => 1,
                    "invoiceLanguage" => 1,
                    "invoiceMethod" => 1,
                    "invoiceReminder" => 1,
                    "contractContact" => 1,
                    "discount" => 1,
                    "invoiceContactId" => 1,
                    "withoutVAT" => 1,
                    "gAccount" => 1,
                    "gAccountPercentage" => 1,
                    "normalAccountPercentage" => 1,
                    "gAccountNumber" => 1,
                    "deviationContractAgreement" => 1,
                    "logoFileName" => 1,
                    "bankAddress" => 1,
                    "noticeTerm" => 1,
                    "invoicingAgenda" => 1,
                    "paymentCondition" => 1,
                    "Project" => 1,
                    "sendCustomerToAfas" => 1,
                    "companyRelations" => 1,
                    "advancedXmlFeeds" => 1,
                    "clientMoods" => 1,
                    "salesCount" => 1,
                    "InvoicingSettings" => [
                        "invoiceFormatNr" => 1,
                        "invoiceCreditFormatNr" => 1,
                        "adminCode" => 1
                    ],
                    "NetworkText" => [
                        "network" => 1,
                        "portfolio" => 1,
                        "reference" => 1
                    ],
                    "ExtraFields" => [
                        "fieldName" => 1,
                        "fieldValue" => 1
                    ],
                    "ConfigurableOrganisationUnits" => [
                        "unitId" => 1,
                        "unitItemId" => 1
                    ],
                    "SocialNetworks" => [
                        "socialNetwork" => 1,
                        "socialNetworkId" => 1,
                        "url" => 1,
                        "description" => 1,
                        "logoUrl" => 1
                    ]
                ],
                null
            ],
            "id" => 1
        ];

        // Do OWS API Request
        $post = $this->post($matchCriteriaRequest);

        // Check if the api call was succesfull and get the result
        if ($post && ($result  = $post)) {
            // Return the new generated match criteria list
            return $result;
        }

        return [];
    }

    /**
     * Get relation by Customer ID
     *
     * @param string $customerId | Expected format xxxx.xx.xxxx. Customer ID can be found
     * in the OTYS Go CRM.
     * @return array
     */
    public function getRelationByCustomerId(string $customerId): array
    {
        $request = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.RelationService.getList",
            "params" => [
                $this->otysApi->session,
                [
                    "what" => [
                        "uid" => 1,
                        "relation" => 1,
                        "city" => 1
                    ],
                    "condition" => [
                        "type" => "AND",
                        "items" => [
                            [
                                "type" => "COND",
                                "field" => "customerNr",
                                "op" => "LIKE",
                                "param" => "%{$customerId}%"
                            ]
                        ]
                    ],
                    "limit" => 1
                ]
            ],
            "id" => 1
        ];

        $response = $this->post($request, true, false);

        if (!empty($response) && is_array($response) && isset($response[0])) {
            return $response[0];
        }

        return [];
    }
}
