<?php

namespace Otys\OtysPlugin\Models\Admin;

use Otys\OtysPlugin\Includes\OtysApi\OtysApi;

class AdminSettingsModel extends AdminBaseModel
{
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Create default documents
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDefaultDocuments($apiKey)
    {
        static::createDocumentNewCandidate($apiKey);
        static::createDocumentExistingCandidate($apiKey);
        static::createDocumentOpenCandidate($apiKey);
        static::documentConsultantNotification($apiKey);
        static::createDocumentConfirmEmail($apiKey);
    }
    
    /**
     * Create document which is used for emailing a candidate
     * when the candidate is applying on a vacancy and is a
     * new candidate.
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentNewCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Nieuwe kandidaat sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor je sollicitatie op de vacature: ««Vacatures.Functienaam»».</p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );
        $otysApi->documents->createQuestion($snippetIdNl, 'code', 'code', 'code', 'textField', 'nl');

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Nieuwe kandidaat sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'subject' => 'Bevestiging sollicitatie',
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | New candidate application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for applying on the vacancy ««Vacatures.Functienaam»».</p>
                Kind regards,<br />',
                true,
                'en'
            );
            $otysApi->documents->createQuestion($snippetIdEn, 'password', 'password', 'password', 'textField', 'en');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | New candidate application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'subject' => 'Application confirmation',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'en');

            /**
             * French language
             */
            $snippetIdFr = $otysApi->documents->createSnippet(
                'WordPress | Confirmer l\'e-mail (par défaut)',
                '<p>Bonjour ««Kandidaten.Voornaam»»,</p>
                <p>Merci pour votre candidature au poste de ««Vacatures.Functienaam»».</p>
                Cordialement,<br/>',
                true,
                'fr'
            );
            $otysApi->documents->createQuestion($snippetIdFr, 'password', 'password', 'password', 'textField', 'fr');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'fr');
            
            $documentNameFr = 'WordPress | Confirmer l\'e-mail (par défaut)';
            $documentIdFr = $otysApi->documents->createDocument($documentNameFr, [
                'name' => $documentNameFr,
                'subject' => 'Confirmation de candidature',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'fr');

            /**
             * German language
             */
            $snippetIdDe = $otysApi->documents->createSnippet(
                'WordPress | Neue Kandidatenbewerbung (Standard)',
                '<p>Sehr geehrter ««Kandidaten.Voornaam»»,</p>
                <p>Vielen Dank für Ihre Bewerbung auf das Stellenangebot: ««Vacatures.Functienaam»».</p>
                Mit freundlichen Grüßen,<br />',
                true,
                'de'
            );
            $otysApi->documents->createQuestion($snippetIdDe, 'password', 'password', 'password', 'textField', 'de');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'de');
            
            $documentNameDe = 'WordPress | Neue Kandidatenbewerbung (Standard)';
            $documentIdDe = $otysApi->documents->createDocument($documentNameDe, [
                'name' => $documentNameDe,
                'subject' => 'Bewerbungsbestätigung',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'de');

            /**
             * Spanish language
             */
            $snippetIdEs = $otysApi->documents->createSnippet(
                'WordPress | Solicitud de nuevo candidato (predeterminado)',
                '<p>Estimado/a ««Kandidaten.Voornaam»»,</p>
                <p>Gracias por su solicitud para la vacante: ««Vacatures.Functienaam»».</p>
                Atentamente,<br />',
                true,
                'es'
            );
            $otysApi->documents->createQuestion($snippetIdEs, 'password', 'password', 'password', 'textField', 'es');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'es');
            
            $documentNameEs = 'WordPress | Solicitud de nuevo candidato (predeterminado)';
            $documentIdEs = $otysApi->documents->createDocument($documentNameEs, [
                'name' => $documentNameEs,
                'subject' => 'Confirmación de la solicitud',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'es');

            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
            $otysApi->documents->addSnippetToDocument($snippetIdFr, $documentIdFr, 'fr');
            $otysApi->documents->addSnippetToDocument($snippetIdDe, $documentIdDe, 'de');
            $otysApi->documents->addSnippetToDocument($snippetIdEs, $documentIdEs, 'es');
        }
    }

    /**
     * Create document which is used when emailing a candidate when
     * the candidate already exists in OTYS and applies for a new job.
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentExistingCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Bestaande kandidaat sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor je sollicitatie op de vacature: ««Vacatures.Functienaam»».</p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );
        $otysApi->documents->createQuestion($snippetIdNl, 'code', 'code', 'code', 'textField', 'nl');

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Bestaande kandidaat sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'subject' => 'Bevestiging sollicitatie',
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'Wordpress | Existing candidate application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for applying on the vacancy ««Vacatures.Functienaam»».</p>
                Kind regards,<br />',
                true,
                'en'
            );
            $otysApi->documents->createQuestion($snippetIdEn, 'code', 'code', 'code', 'textField', 'en');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'Wordpress | Existing candidate application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'subject' => 'Application confirmation',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'en');

            /**
             * French language
             */
            $snippetIdFr = $otysApi->documents->createSnippet(
                'WordPress | Candidature existante (par défaut)',
                '<p>Bonjour ««Kandidaten.Voornaam»»,</p>
                <p>Merci pour votre candidature au poste de ««Vacatures.Functienaam»».</p>
                Cordialement,<br/>',
                true,
                'fr'
            );
            $otysApi->documents->createQuestion($snippetIdFr, 'code', 'code', 'code', 'textField', 'fr');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'fr');
            
            $documentNameFr = 'WordPress | Candidature existante (par défaut)';
            $documentIdFr = $otysApi->documents->createDocument($documentNameFr, [
                'name' => $documentNameFr,
                'subject' => 'Confirmation de candidature',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'fr');

            /**
             * German language
             */
            $snippetIdDe = $otysApi->documents->createSnippet(
                'WordPress | Vorhandene Kandidatenbewerbung (Standard)',
                '<p>Sehr geehrter ««Kandidaten.Voornaam»»,</p>
                <p>Sie bewerben sich auf das Stellenangebot: ««Vacatures.Functienaam»».</p>
                <p>Bitte geben Sie den folgenden Code auf der Website ein, um Ihre Bewerbung abzuschließen: «code».</p>
                Mit freundlichen Grüßen, <br/>',
                true,
                'de'
            );
            $otysApi->documents->createQuestion($snippetIdDe, 'code', 'code', 'code', 'textField', 'de');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'de');
            
            $documentNameDe = 'WordPress | Vorhandene Kandidatenbewerbung (Standard)';
            $documentIdDe = $otysApi->documents->createDocument($documentNameDe, [
                'name' => $documentNameDe,
                'subject' => 'Bewerbungsbestätigung',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'de');

            /**
             * Spanish language
             */
            $snippetIdEs = $otysApi->documents->createSnippet(
                'WordPress | Solicitud de candidato existente (predeterminada)',
                '<p>Estimado/a ««Kandidaten.Voornaam»»,</p>
                <p>Gracias por su solicitud para la vacante: ««Vacatures.Functienaam»».</p>
                Atentamente, <br/>',
                true,
                'es'
            );
            $otysApi->documents->createQuestion($snippetIdEs, 'code', 'code', 'code', 'textField', 'es');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'es');
            
            $documentNameEs = 'WordPress | Solicitud de candidato existente (predeterminada)';
            $documentIdEs = $otysApi->documents->createDocument($documentNameEs, [
                'name' => $documentNameEs,
                'subject' => 'Confirmación de la solicitud',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'es');

            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
            $otysApi->documents->addSnippetToDocument($snippetIdFr, $documentIdFr, 'fr');
            $otysApi->documents->addSnippetToDocument($snippetIdDe, $documentIdDe, 'de');
            $otysApi->documents->addSnippetToDocument($snippetIdEs, $documentIdEs, 'es');
        }
    }

    /**
     * Creat a document which is used for emailing the consultant if
     * a candidate applied for a job which the consultant is the owner
     * of.
     *
     * @return void
     * @since 1.1.0
     */
    public static function documentConsultantNotification($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Consultant sollicitatie notificatie (default)',
            '<p>Een kandidaat heeft gesolliciteerd op de vacature ««Vacatures.Functienaam»»</p>
            <p>Kandidaat informatie:</p>
            <p>
                <b>Naam:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br/>
                <b>Email:</b> ««Kandidaten.Email»»<br/>
                <b>Mobiel:</b> ««Kandidaten.MobilePhone»»<br/>
                <b>Stad:</b> ««Kandidaten.Woonplaats»»
            </p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Consultant sollicitatie notificatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Consultant application notification (default)',
                '<p>A candidate has applied for ««Vacatures.Functienaam»»</p>
                <p>Candidate information:</p>
                <p>
                    <b>Name:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br/>
                    <b>E-mail:</b> ««Kandidaten.Email»»<br/>
                    <b>Mobile:</b> ««Kandidaten.MobilePhone»»<br/>
                    <b>City:</b> ««Kandidaten.Woonplaats»»
                </p>
                Kind regards,<br />',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Consultant application notification (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * French language
             */
            $snippetIdFr = $otysApi->documents->createSnippet(
                'WordPress | Notification de demande de consultant (par défaut)',
                '<p>Une candidat.e a postulé au poste de ««Vacatures.Functienaam»».</p>
                <p><b>A propos du/de la candidate:</b></p>
                <p>
                    <b>Nom:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Achternaam»»<br />
                    <b>Adresse </b>mail: ««Kandidaten.Email»»<br />
                    <b>Portable:</b> ««Kandidaten.MobilePhone»»<br />
                    <b>Ville:</b> ««Kandidaten.Woonplaats»»
                </p>
                Cordialement,<br />',
                true,
                'fr'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'fr');
            
            $documentNameFr = 'WordPress | Notification de demande de consultant (par défaut)';
            $documentIdFr = $otysApi->documents->createDocument($documentNameFr, [
                'name' => $documentNameFr,
                'subject' => 'Confirmation de candidature',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'fr');

            /**
             * German language
             */
            $snippetIdDe = $otysApi->documents->createSnippet(
                'WordPress | Benachrichtigung zur Beraterbewerbung (Standard)',
                '<p>Ein Bewerber hat sich auf die Stelle ««Vacatures.Functienaam»» beworben.</p>
                <p><b>Informationen über den Kandidaten:</b></p>
                <p>
                    <b>Name:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br />
                    <b>E-Mail</b>: ««Kandidaten.Email»»<br />
                    <b>Mobil:</b> ««Kandidaten.MobilePhone»»<br />
                    <b>Stadt:</b> ««Kandidaten.Woonplaats»»
                </p>    
                Mit freundlichen Grüßen,<br />',
                true,
                'de'
            );

            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'de');
            
            $documentNameDe = 'WordPress | Benachrichtigung zur Beraterbewerbung (Standard)';
            $documentIdDe = $otysApi->documents->createDocument($documentNameDe, [
                'name' => $documentNameDe,
                'subject' => 'Bewerbungsbestätigung',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'de');

            /**
             * Spanish language
             */
            $snippetIdEs = $otysApi->documents->createSnippet(
                'WordPress | Notificación de solicitud de consultor (predeterminado)',
                '<p>Un candidato ha solicitado para la vacante ««Vacatures.Functienaam»»</p>
                <p><b>Información del candidato:</b></p>
                <p> 
                    <b>Nombre:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br />
                    <b>Correo electrónico</b>: ««Kandidaten.Email»»<br />
                    <b>Teléfono celular</b>: ««Kandidaten.MobilePhone»»<br />
                    <b>Ciudad:</b> ««Kandidaten.Woonplaats»
                </p>
                Atentamente,<br />',
                true,
                'es'
            );

            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'es');
            
            $documentNameEs = 'WordPress | Notificación de solicitud de consultor (predeterminado)';
            $documentIdEs = $otysApi->documents->createDocument($documentNameEs, [
                'name' => $documentNameEs,
                'subject' => 'Confirmación de la solicitud',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'es');

            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
            $otysApi->documents->addSnippetToDocument($snippetIdFr, $documentIdFr, 'fr');
            $otysApi->documents->addSnippetToDocument($snippetIdDe, $documentIdDe, 'de');
            $otysApi->documents->addSnippetToDocument($snippetIdEs, $documentIdEs, 'es');
        }
    }

    /**
     * Create a document which is used for emailing the candidate
     * when the candidate did an open application
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentOpenCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Open sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor jouw open inschrijving.</p>
            <p>Wij zullen z.s.m. contact met je opnemen.</p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Open sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Open application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for your open application.</p>
                <p>We will contact you as soon as possible.</p>
                Kind regards,<br />',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Open application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * French language
             */
            $snippetIdFr = $otysApi->documents->createSnippet(
                'WordPress | Ouvrir l\'application (par défaut)',
                '<p>Bonjour ««Kandidaten.Voornaam»»,</p>
                <p>Merci pour votre candidature spontanée.</p>
                <p>Nous allons vous contacter dans les plus brefs délais.</p>
                Cordialement,<br />',
                true,
                'fr'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'fr');
            
            $documentNameFr = 'WordPress | Ouvrir l\'application (par défaut)';
            $documentIdFr = $otysApi->documents->createDocument($documentNameFr, [
                'name' => $documentNameFr,
                'subject' => 'Confirmation de candidature',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'fr');

            /**
             * German language
             */
            $snippetIdDe = $otysApi->documents->createSnippet(
                'WordPress | Anwendung öffnen (Standard)',
                '<p>Sehr geehrter ««Kandidaten.Voornaam»»,</p>
                <p>Wir danken Ihnen für Ihre offene Anmeldung.</p>
                <p>Wir werden Sie so bald wie möglich kontaktieren.</p>
                Mit freundlichen Grüßen,<br />',
                true,
                'de'
            );

            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'de');
            
            $documentNameDe = 'WordPress | Anwendung öffnen (Standard)';
            $documentIdDe = $otysApi->documents->createDocument($documentNameDe, [
                'name' => $documentNameDe,
                'subject' => 'Bewerbungsbestätigung',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'de');

            /**
             * Spanish language
             */
            $snippetIdEs = $otysApi->documents->createSnippet(
                'WordPress | Abrir aplicación (predeterminado)',
                '<p>Estimado/a ««Kandidaten.Voornaam»», </p>
                <p>Gracias por su licitación. </p>
                <p>Nos pondremos en contacto con usted lo más pronto posible. </p>
                Atentamente,<br />',
                true,
                'es'
            );

            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'es');
            
            $documentNameEs = 'WordPress | Abrir aplicación (predeterminado)';
            $documentIdEs = $otysApi->documents->createDocument($documentNameEs, [
                'name' => $documentNameEs,
                'subject' => 'Confirmación de la solicitud',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'es');

            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
            $otysApi->documents->addSnippetToDocument($snippetIdFr, $documentIdFr, 'fr');
            $otysApi->documents->addSnippetToDocument($snippetIdDe, $documentIdDe, 'de');
            $otysApi->documents->addSnippetToDocument($snippetIdEs, $documentIdEs, 'es');
        }
    }

    /**
     * Create a document which is used for sending the candidate a
     * confirmation email
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentConfirmEmail($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Bevestig email (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Je bent aan het solliciteren op de vacature: ««Vacatures.Functienaam»».</p>
            <p>Vul de volgende code op de website in om je sollicitatie af te ronden: «code»</p>
            Met vriendelijke groet,<br/>',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Bevestig email (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'subject' => 'Bevestig jouw email',
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Confirm email (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>You are applying for the vacancy: ««Vacatures.Functienaam»».</p>
                <p>Enter the following code on the website to complete your application: «code»</p>
                With kind regards,<br/>',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Confirm email (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'subject' => 'Confirm your email',
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


             /**
             * French language
             */
            $snippetIdFr = $otysApi->documents->createSnippet(
                'WordPress | Confirmer l\'e-mail (par défaut)',
                '<p>Bonjour ««Kandidaten.Voornaam»»,</p>
                <p>Vous êtes en train de postuler pour le poste de ««Vacatures.Functienaam»».</p>
                <p>Veuillez entrer le code suivant pour compléter votre candidature : «code».</p>
                Cordialement, <br />',
                true,
                'fr'
            );
            $otysApi->documents->createQuestion($snippetIdFr, 'code', 'code', 'code', 'textField', 'fr');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'fr');
            
            $documentNameFr = 'WordPress | Confirmer l\'e-mail (par défaut)';
            $documentIdFr = $otysApi->documents->createDocument($documentNameFr, [
                'name' => $documentNameFr,
                'subject' => 'Confirmez votre email',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'fr');

            /**
             * German language
             */
            $snippetIdDe = $otysApi->documents->createSnippet(
                'WordPress | Bestätigungs-E-Mail (Standard)',
                '<p>Sehr geehrter ««Kandidaten.Voornaam»»,</p>
                <p>Sie bewerben sich auf das Stellenangebot: ««Vacatures.Functienaam»».</p>
                <p>Bitte geben Sie den folgenden Code auf der Website ein, um Ihre Bewerbung abzuschließen: «code».</p>
                Mit freundlichen Grüßen, <br/>',
                true,
                'de'
            );
            $otysApi->documents->createQuestion($snippetIdDe, 'code', 'code', 'code', 'textField', 'de');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'de');
            
            $documentNameDe = 'WordPress | Bestätigungs-E-Mail (Standard)';
            $documentIdDe = $otysApi->documents->createDocument($documentNameDe, [
                'name' => $documentNameDe,
                'subject' => 'Bestätigungs-E-Mail',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'de');

            /**
             * Spanish language
             */
            $snippetIdEs = $otysApi->documents->createSnippet(
                'WordPress | Confirmar correo electrónico (Standard)',
                '<p>Estimado/a ««Kandidaten.Voornaam»»,</p>
                <po>Está solicitando para la vacante: ««Vacatures.Functienaam»».</p>
                <p>Por favor, introduzca el siguiente código en el sitio para completar su solicitud: «code».</p>
                Atentamente,<br />',
                true,
                'es'
            );
            $otysApi->documents->createQuestion($snippetIdEs, 'code', 'code', 'code', 'textField', 'es');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'es');
            
            $documentNameEs = 'WordPress | Confirmar correo electrónico (Standard)';
            $documentIdEs = $otysApi->documents->createDocument($documentNameEs, [
                'name' => $documentNameEs,
                'subject' => 'Confirmar correo electrónico',
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'parentUid' => $documentId
            ], 'es');

            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
            $otysApi->documents->addSnippetToDocument($snippetIdFr, $documentIdFr, 'fr');
            $otysApi->documents->addSnippetToDocument($snippetIdDe, $documentIdDe, 'de');
            $otysApi->documents->addSnippetToDocument($snippetIdEs, $documentIdEs, 'es');
        }
    }
}
