<?php

global $wp;

$args = wp_parse_args(
    $args,
    array(
        'questionset' => [],
        'errors' => []
    )
);

if (empty($args['questionset'])) {
    return;
}

$currentQuestionPageNumber = (int) $args['questionset']['currentPage'];
$totalQuestionPages = count($args['questionset']['pages']);
$currentQuestionPage = $args['questionset']['pages'][$currentQuestionPageNumber];

?>

<section id="vacancy-form" class="vacancy-spacing">
    <form method="POST" class="form_default" enctype="multipart/form-data" id="application-form" name="application-form">
        
        <?php if (!empty($args['errors']) && isset($args['errors']['recaptcha'])) : ?>
        <div class="vacancy-form-errors">
            <div class="vacancy-form-error">
                <?php echo esc_html($args['errors']['recaptcha']); ?>
            </div>
        </div>
        <?php endif; ?>

        <?php
        foreach ($currentQuestionPage['questions'] as $question) {
            if ($question['template'] === false) {
                continue;
            }

            if (isset($args['formData'][$question['id']])) {
                $question['value'] = $args['formData'][$question['id']];
            }

            ?>
            <div class="row form-input-wrapper">
                <div class="col-md-4">
                    <label for="vacancy-form-email"><?php echo isset($question['data']['question']) ? esc_html($question['data']['question']) : '' ?><?php echo ($question['validation']['mandatory']) ? '*' : '' ?></label>
                </div>

                <div class="col-md-8">
                    <div class="input-wrap">
                        <div class="input-field">
                            <?php
                            load_template(
                                $question['template'],
                                false,
                                [
                                    'question' => $question,
                                    'uid' => $args['questionset']['uid'],
                                    'ajaxUrl' => $args['ajaxUrl']
                                ]
                            );
                            ?>
                        </div>

                        <?php
                        // If there are errors, display the error
                        if (array_key_exists($question['id'], $args['errors'])) {
                            ?>
                            <div class="input_errors">
                            <?php
                                load_template(
                                    OTYS_PLUGIN_TEMPLATE_URL . '/include-parts/forms/field-error.php',
                                    false,
                                    [
                                        'errors' => $args['errors'][$question['id']]
                                    ]
                                );
                            ?>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                </div>
            </div>
            <?php
        }
        ?>

        <div class="form_footer">
            <input type="hidden" name="action" value="openapplication" />
            <input type="hidden" name="redirect" value="<?php echo $args['redirect'] ?>" />

            <?php if ($currentQuestionPageNumber === $totalQuestionPages) : ?>
                <button class="g-recaptcha button vacancy_apply_button" data-sitekey="<?php echo esc_attr(get_option('otys_option_recaptcha_site_key')) ?>" data-callback='onSubmit' data-action='submit'><?php echo __('apply', 'otys-jobs-apply'); ?></button>
            <?php else : ?>
                <button class="button vacancy_apply_button" type="submit"><?php echo __('apply', 'otys-jobs-apply'); ?></button>
            <?php endif; ?>
        </div>
    </form>
</section>



<script>
    function onSubmit(token) {
        document.getElementById("application-form").submit();
    }
</script>